@@ -69,7 +69,7 @@ def session(ctx: click.core.Context, build_name: str, save_session_file: bool, p
 
         if res.status_code == HTTPStatus.NOT_FOUND:
             click.echo(click.style(
-                "Build {} was not found. Make sure to run `launchable record build --name {}` before".format(build_name, build_name), 'yellow'), err=True)
+                "Build {} was not found. Make sure to run `launchable record build --name {}` before you run this command.".format(build_name, build_name), 'yellow'), err=True)
             sys.exit(1)
 
         res.raise_for_status()
